import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"

from mandaw.main import Mandaw
from mandaw.gameobject import GameObject
from mandaw.line import Line
from mandaw.color import Color
from mandaw.sprite import Sprite
from mandaw.text import Text
from mandaw.input import Controls
from mandaw.audio import Audio
from mandaw.animation import Animation
from mandaw.light import Light



from pygame import mixer

class Audio:
    def __init__(self, file, volume):
        self.volume = volume

        mixer.Sound(file)
        mixer.Sound.set_volume(self.volume)

    def play(self):
        mixer.Sound.play()

    def stop(self):
        mixer.Sound.stop()



import pygame

class Controls:
    def __init__(self):
        self.pressed = pygame.key.get_pressed()

    def update(self):
        self.pressed = pygame.key.get_pressed()

    def is_key_pressed(self, key):
        return self.pressed[key]



import pygame

class Sprite:
    def __init__(self, window, image, x, y, size = (200, 200)):
        self.animations = {}
        self.image = pygame.image.load(image)
        if size is not None:
            self.image = pygame.transform.scale(self.image, size)
        self.window = window
        self.x = x
        self.y = y
        self.size = size
        self.rect = pygame.Rect(0, 0, 0, 0)

    def draw(self):
        self.rect = pygame.Rect(self.x, self.y, self.size[0], self.size[1])
        self.window.window.blit(self.image, (self.x, self.y))


    def get_width(self):
        return self.image.get_width()

    def get_height(self):
        return self.image.get_height()

    def center(self):
        self.x = self.window.width / 2 - self.size[0]
        self.y = self.window.height / 2 - self.size[1]

    def center_x(self):
        self.x = self.window.width / 2 - self.size[0]

    def center_y(self):
        self.y = self.window.height / 2 - self.size[1]

    def collide(self, rect):
        if type(rect) != list:
            return self.rect.colliderect(rect)
        elif type(rect) == list:
            return self.rect.collidelistall(rect)
        else:
            print("MandawError: sorry but when you typed collide(object), the object wasnt a string or a list. see "
                  "you soon :)")

    def resize(self, size):
        self.image = pygame.transform.scale(self.image, size)

    def add_animation(self, animation, name):
        self.animations[name] = {"frames": animation.frames, "length": animation.count, "cooldown": animation.anim_time,
                                 "count": 0, "folder": animation.folder}

    def play_animation(self, name, mirror=None):
        for i in self.animations:
            if i != name:
                self.animations[i]["count"] = 0
            else:
                self.animations[i]["count"] += self.animations[i]["cooldown"]
                if self.animations[i]["count"] >= self.animations[i]["length"]:
                    self.animations[i]["count"] = 0

                if self.size is None:
                    if mirror is None:
                        self.image = pygame.image.load(self.animations[i]["folder"] + "/" +
                                                       self.animations[i]["frames"][int(self.animations[i]["count"])])
                    elif mirror == "x":
                        self.image = pygame.transform.flip(pygame.image.load(self.animations[i]["folder"] + "/" +
                                                                             self.animations[i]["frames"][
                                                                                 int(self.animations[i]["count"])]),
                                                           True, False)
                    elif mirror == "y":
                        self.image = pygame.transform.flip(pygame.image.load(self.animations[i]["folder"] + "/" +
                                                                             self.animations[i]["frames"][
                                                                                 int(self.animations[i]["count"])]),
                                                           True, False)
                else:
                    if mirror is None:
                        self.image = pygame.transform.scale(pygame.image.load(self.animations[i]["folder"] + "/" +
                                                                              self.animations[i]["frames"][
                                                                                  int(self.animations[i]["count"])]),
                                                            self.size)
                    elif mirror == "x":
                        self.image = pygame.transform.flip(
                            pygame.transform.scale(pygame.image.load(self.animations[i]["folder"] + "/" +
                                                                     self.animations[i]["frames"][
                                                                         int(self.animations[i]["count"])]),
                                                   self.size), True, False)
                    elif mirror == "y":
                        self.image = pygame.transform.flip(
                            pygame.transform.scale(pygame.image.load(self.animations[i]["folder"] + "/" +
                                                                     self.animations[i]["frames"][
                                                                         int(self.animations[i]["count"])]),
                                                   self.size),
                            True, False)

                self.draw()



import pygame

class Line:
    def __init__(self, window, color, start_pos, end_pos):   
        self.window = window
        self.color = color
        self.start_pos = start_pos
        self.end_pos = end_pos

        pygame.draw.aaline(self.window.window, self.color, self.start_pos, self.end_pos)



import pygame

class Text:
    def __init__(self, window, text, font_size = 24, style = None, color = "white", x = 0, y = 0):
        self.window = window
        self.font_size = font_size
        self.style = style
        self.font = pygame.font.SysFont(self.style, self.font_size)
        self.color = color
        self.x = x
        self.y = y

        self.text = self.font.render(text, True, self.color)

    def draw(self):
        self.window.window.blit(self.text, (self.x, self.y))

    def center(self):
        self.x = self.window.width / 2 - self.font_size / 2
        self.y = self.window.height / 2 - self.font_size / 2



from typing import Union

import pygame
from pygame.surface import Surface, SurfaceType

import mandaw


class Light:
    light_mask: Union[Surface, SurfaceType]
    light_filter: Surface

    def __init__(self, window: mandaw.Mandaw, mask_img):
        self.window = window
        self.mask = mask_img

    def light_init(self, pos):
        self.pos = pos
        self.light_mask = pygame.image.load(self.mask)
        self.light_filter = pygame.surface.Surface((self.window.width, self.window.height))
        self.light_filter.fill(pygame.color.Color("Gray"))
        self.light_filter.blit(self.light_mask, pos)
    def draw(self):
        self.window.window.blit(self.light_filter, (0, 0), special_flags=pygame.BLEND_RGBA_SUB)




import os

class Animation:
    def __init__(self, anim_folder, anim_time):
        self.frames = []
        self.anim_time = anim_time
        self.folder = anim_folder
        
        for f in os.listdir(anim_folder):
            if os.path.splitext(f)[1] == ".png":
                self.frames.append(f)

        self.frames = sorted(self.frames)
        self.count = len(self.frames)



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
      name='mandaw',
      version='1.0.9',
      description='A Game Engine Made In Python',
      long_description=long_description,
      long_description_content_type="text/markdown",
      author='mandaw2014',
      author_email='mandawbuisness@gmail.com',
      url='https://mandaw2014.github.io/MandawEngine/',
      packages=['mandaw'],
      package_dir={'':'mandaw_engine'},
      python_requires=">=3.6",
      install_requires=["pygame"]
)